@@ -1,13 +1,9 @@
 from urllib3.exceptions import ProtocolError
 
-from ocp_resources.logger import get_logger
 from ocp_resources.resource import NamespacedResource
 from ocp_resources.utils import TimeoutExpiredError, TimeoutSampler
 
 
-LOGGER = get_logger(name=__name__)
-
-
 class CatalogSourceConfig(NamespacedResource):
     api_group = NamespacedResource.ApiGroup.OPERATORS_COREOS_COM
 
@@ -77,5 +73,7 @@ class CatalogSourceConfig(NamespacedResource):
 
         except TimeoutExpiredError:
             if current_status:
-                LOGGER.error(f"Status of {self.kind} {self.name} is {current_status}")
+                self.logger.error(
+                    f"Status of {self.kind} {self.name} is {current_status}"
+                )
             raise
