@@ -5,6 +5,7 @@ from distutils.version import Version
 
 import kubernetes
 import urllib3
+import yaml
 from openshift.dynamic import DynamicClient
 from openshift.dynamic.exceptions import (
     ConflictError,
@@ -215,8 +216,6 @@ class ValueMismatch(Exception):
     Raises when value doesn't match the class value
     """
 
-    pass
-
 
 class Resource(object):
     """
@@ -336,6 +335,8 @@ class Resource(object):
         self.name = name
         self.client = client
         self.privileged_client = privileged_client
+        self.logger = get_logger(name=f"{__name__.rsplit('.')[0]} {self.kind}")
+
         if not self.client:
             try:
                 self.client = DynamicClient(
@@ -345,7 +346,7 @@ class Resource(object):
                 kubernetes.config.ConfigException,
                 urllib3.exceptions.MaxRetryError,
             ):
-                LOGGER.error(
+                self.logger.error(
                     "You need to be logged into a cluster or have $KUBECONFIG env configured"
                 )
                 raise
@@ -388,13 +389,13 @@ class Resource(object):
     def clean_up(self):
         if os.environ.get("CNV_TEST_COLLECT_LOGS", "0") == "1":
             try:
-                LOGGER.info(f"Collecting data for {self.kind} {self.name}")
+                self.logger.info(f"Collecting data for {self.kind} {self.name}")
                 _collect_data(resource_object=self)
             except Exception as exception_:
-                LOGGER.warning(exception_)
+                self.logger.warning(exception_)
 
         data = self.to_dict()
-        LOGGER.info(f"Deleting {data}")
+        self.logger.info(f"Deleting {data}")
         self.delete(wait=True, timeout=self.timeout)
 
     @classmethod
@@ -445,7 +446,7 @@ class Resource(object):
         Raises:
             TimeoutExpiredError: If resource not exists.
         """
-        LOGGER.info(f"Wait until {self.kind} {self.name} is created")
+        self.logger.info(f"Wait until {self.kind} {self.name} is created")
         samples = TimeoutSampler(
             wait_timeout=timeout,
             sleep=sleep,
@@ -466,7 +467,7 @@ class Resource(object):
         Raises:
             TimeoutExpiredError: If resource still exists.
         """
-        LOGGER.info(f"Wait until {self.kind} {self.name} is deleted")
+        self.logger.info(f"Wait until {self.kind} {self.name} is deleted")
         return self.client_wait_deleted(timeout=timeout)
 
     @property
@@ -509,7 +510,7 @@ class Resource(object):
             TimeoutExpiredError: If resource in not in desire status.
         """
         stop_status = stop_status if stop_status else self.Status.FAILED
-        LOGGER.info(f"Wait for {self.kind} {self.name} status to be {status}")
+        self.logger.info(f"Wait for {self.kind} {self.name} status to be {status}")
         samples = TimeoutSampler(
             wait_timeout=timeout,
             sleep=sleep,
@@ -535,15 +536,16 @@ class Resource(object):
 
         except TimeoutExpiredError:
             if current_status:
-                LOGGER.error(f"Status of {self.kind} {self.name} is {current_status}")
+                self.logger.error(
+                    f"Status of {self.kind} {self.name} is {current_status}"
+                )
             raise
 
-    def create(self, body=None, wait=False):
+    def create(self, wait=False):
         """
         Create resource.
 
         Args:
-            body (dict): Resource data to create.
             wait (bool) : True to wait for resource status.
 
         Returns:
@@ -553,21 +555,8 @@ class Resource(object):
             ValueMismatch: When body value doesn't match class value
         """
         data = self.to_dict()
-        if body:
-            kind = body["kind"]
-            name = body.get("name")
-            api_version = body["apiVersion"]
-            if kind != self.kind:
-                ValueMismatch(f"{kind} != {self.kind}")
-            if name and name != self.name:
-                ValueMismatch(f"{name} != {self.name}")
-            if api_version != self.api_version:
-                ValueMismatch(f"{api_version} != {self.api_version}")
-
-            data.update(body)
-
-        LOGGER.info(f"Posting {data}")
-        LOGGER.info(f"Create {self.kind} {self.name}")
+        self.logger.info(f"Posting {data}")
+        self.logger.info(f"Create {self.kind} {self.name}")
         res = self.api().create(body=data, namespace=self.namespace)
         if wait and res:
             return self.wait()
@@ -580,7 +569,7 @@ class Resource(object):
         except NotFoundError:
             return False
 
-        LOGGER.info(f"Delete {self.kind} {self.name}")
+        self.logger.info(f"Delete {self.kind} {self.name}")
         if wait and res:
             return self.wait_deleted(timeout=timeout)
         return res
@@ -595,7 +584,7 @@ class Resource(object):
         Returns:
            str: Status
         """
-        LOGGER.info(f"Get {self.kind} {self.name} status")
+        self.logger.info(f"Get {self.kind} {self.name} status")
         return self.instance.status.phase
 
     def update(self, resource_dict):
@@ -605,7 +594,8 @@ class Resource(object):
         Args:
             resource_dict: Resource dictionary
         """
-        LOGGER.info(f"Update {self.kind} {self.name}: {resource_dict}")
+        self.logger.info(f"Update {self.kind} {self.name}:\n{resource_dict}")
+        self.logger.debug(f"\n{yaml.dump(resource_dict)}")
         self.api().patch(
             body=resource_dict,
             namespace=self.namespace,
@@ -617,7 +607,8 @@ class Resource(object):
         Replace resource metadata.
         Use this to remove existing field. (update() will only update existing fields)
         """
-        LOGGER.info(f"Replace {self.kind} {self.name}: {resource_dict}")
+        self.logger.info(f"Replace {self.kind} {self.name}: \n{resource_dict}")
+        self.logger.debug(f"\n{yaml.dump(resource_dict)}")
         self.api().replace(body=resource_dict, name=self.name, namespace=self.namespace)
 
     @staticmethod
@@ -697,7 +688,7 @@ class Resource(object):
         Raises:
             TimeoutExpiredError: If Pod condition in not in desire status.
         """
-        LOGGER.info(
+        self.logger.info(
             f"Wait for {self.kind}/{self.name}'s '{condition}' condition to be '{status}'"
         )
         samples = TimeoutSampler(
